# Installation

Yarrtist requires python>=3.8, and can be obtained by cloning from git or
installing via pip

## git

Clone the repository

```
git clone https://gitlab.cern.ch/YARR/yarrtist.git

```

then `cd` to `yarrtist` and

```
python3 -m venv venv
source venv/bin/activate
pip install -e .

```

to install in `editable` mode.

## pip

YARRtist is available on PyPi

```
python3 -m venv venv
source venv/bin/activate
pip install yarrtist

```
